=================
 Developer guide
=================

API
===

Producers
---------

.. automodule:: poultry.producers
   :members:


Consumers
---------

.. automodule:: poultry.consumers
   :members:

Tweet
-----

.. automodule:: poultry.tweet
   :members:

Stream
------

.. automodule:: poultry.stream
   :members:
